@@ -1,4 +1,4 @@
 from dnastack.constants import *
 from .files_client import *
-from .search_client import *
+from .dataconnect_client import *
 from .auth import *
