@@ -96,6 +96,7 @@ def download_file(
                         object_info = drs_client.get_object_info(object_id)
                     except:
                         click.secho("Access Denied", fg="red")
+                        sys.exit(1)
                 else:
                     click.secho(
                         f"Authorization required for {drs_server}. Please login or configure your email and personal access token",
@@ -201,6 +202,3 @@ def download_files(
 
     for thread in download_threads:
         thread.join()
-
-    if out is None:
-        click.secho("Download complete into " + output_dir, fg="green")
